@@ -10,27 +10,27 @@
 class KateLayoutCache;
 class KateViewInternal;
 
-#include "katerenderer.h"
 #include "ktexteditor/view.h"
-#include "ktexteditor_export.h" // for tests
-
-#include <KConfigGroup>
 
 #include <QKeyEvent>
 
 class KateViewInternal;
+class KConfigGroup;
+class QKeyEvent;
 namespace KTextEditor
 {
 class ViewPrivate;
+enum class caretStyles;
+class Cursor;
 }
 
-class KTEXTEDITOR_EXPORT KateAbstractInputMode
+class KateAbstractInputMode
 {
 protected:
     KateAbstractInputMode(KateViewInternal *);
 
 public:
-    virtual ~KateAbstractInputMode();
+    virtual ~KateAbstractInputMode() = default;
 
     virtual KTextEditor::View::ViewMode viewMode() const = 0;
     virtual QString viewModeHuman() const = 0;
@@ -66,7 +66,7 @@ public:
 
     virtual bool keyPress(QKeyEvent *) = 0;
     virtual bool blinkCaret() const = 0;
-    virtual KateRenderer::caretStyles caretStyle() const = 0;
+    virtual KTextEditor::caretStyles caretStyle() const = 0;
 
     virtual void toggleInsert() = 0;
     virtual void launchInteractiveCommand(const QString &command) = 0;
@@ -75,7 +75,7 @@ public:
 
     /* functions that are currently view private, but vi-mode needs to access them */
 public:
-    void updateCursor(const KTextEditor::Cursor &newCursor);
+    void updateCursor(const KTextEditor::Cursor newCursor);
     KateLayoutCache *layoutCache() const;
     int linesDisplayed() const;
     void scrollViewLines(int offset);
